@@ -19,8 +19,8 @@
 #' decision-making systems by computing and testing the equality of one of
 #' several model-agnostic fairness metrics between protected classes. The
 #' metrics are computed based on a set of true labels and the predictions of an
-#' algorithm. The ratio of these metrics between any unpriveleged protected
-#' class and the priveleged protected class is called parity. This measure can
+#' algorithm. The ratio of these metrics between any unprivileged protected
+#' class and the privileged protected class is called parity. This measure can
 #' quantify potential fairness or discrimination in the algorithms predictions.
 #' Available parity metrics include predictive rate parity, proportional parity,
 #' accuracy parity, false negative rate parity, false positive rate parity, true
@@ -82,29 +82,29 @@
 #'   to the methodology described in Fisher (1970) and Jamil et al. (2017).
 #'
 #'   \itemize{
-#'     \item{Predictive rate parity (\code{prp}): }{calculated as TP / (TP +
+#'     \item{Predictive rate parity (\code{prp}): calculated as TP / (TP +
 #'       FP), its ratio quantifies whether the predictive rate is equal across
 #'       protected classes.}
-#'     \item{Proportional parity (\code{pp}): }{calculated as (TP + FP) / (TP +
+#'     \item{Proportional parity (\code{pp}): calculated as (TP + FP) / (TP +
 #'       FP + TN + FN), its ratio quantifies whether the positive prediction
 #'       rate is equal across protected classes.}
-#'     \item{Accuracy parity (\code{ap}): }{calculated as (TP + TN) / (TP + FP +
+#'     \item{Accuracy parity (\code{ap}): calculated as (TP + TN) / (TP + FP +
 #'       TN + FN), quantifies whether the accuracy is the same across groups.}
-#'     \item{False negative rate parity (\code{fnrp}): }{calculated as FN / (FP
+#'     \item{False negative rate parity (\code{fnrp}): calculated as FN / (FP
 #'       + FN), quantifies whether the false negative rate is the same across
 #'       groups.}
-#'     \item{False positive rate parity (\code{fprp}): }{calculated as FP / (TN
-#'       + FP), quantifes whether the false positive rate is the same across
+#'     \item{False positive rate parity (\code{fprp}): calculated as FP / (TN
+#'       + FP), quantifies whether the false positive rate is the same across
 #'       groups.}
-#'     \item{True positive rate parity (\code{tprp}): }{calculated as TP / (TP +
+#'     \item{True positive rate parity (\code{tprp}): calculated as TP / (TP +
 #'       FN), quantifies whether the true positive rate is the same across
 #'       groups.}
-#'     \item{Negative predicted value parity (\code{npvp}): }{calculated as TN /
+#'     \item{Negative predicted value parity (\code{npvp}): calculated as TN /
 #'       (TN + FN), quantifies whether the negative predicted value is equal
 #'       across groups.}
-#'     \item{Specificity parity (\code{sp}): }{calculated as TN / (TN + FP),
+#'     \item{Specificity parity (\code{sp}): calculated as TN / (TN + FP),
 #'       quantifies whether the true positive rate is the same across groups.}
-#'     \item{Demographic parity (\code{dp}): }{calculated as TP + FP, quantifies
+#'     \item{Demographic parity (\code{dp}): calculated as TP + FP, quantifies
 #'       whether the positive predictions are equal across groups.}
 #'   }
 #'
@@ -153,7 +153,7 @@
 #'   for discrimination-free classification. In \emph{Data Mining and Knowledge
 #'   Discovery}. Springer Science and Business Media LLC.
 #'   \doi{10.1007/s10618-010-0190-x}
-#' @references Chouldechova, A. (2017). Fair Pprediction with disparate impact:
+#' @references Chouldechova, A. (2017). Fair prediction with disparate impact:
 #'   A study of bias in recidivism prediction instruments. In \emph{Big Data}.
 #'   Mary Ann Liebert Inc. \doi{10.1089/big.2016.0047}
 #' @references Feldman, M., Friedler, S. A., Moeller, J., Scheidegger, C., &
@@ -252,6 +252,7 @@ model_fairness <- function(data,
     confmat[[group]][["fp"]] <- fp <- sum(confmat[[group]][["matrix"]][negative, positive])
     confmat[[group]][["tn"]] <- tn <- sum(confmat[[group]][["matrix"]][negative, negative])
     confmat[[group]][["fn"]] <- fn <- sum(confmat[[group]][["matrix"]][positive, negative])
+    confmat[[group]][["n"]] <- sum(confmat[[group]][["matrix"]])
     # Performance measures for each group
     performance[[group]][["support"]] <- performance[["all"]][i, 1] <- sum(confmat[[group]][["matrix"]])
     performance[[group]][["accuracy"]] <- performance[["all"]][i, 2] <- (confmat[[group]][["tp"]] + confmat[[group]][["tn"]]) / (confmat[[group]][["tp"]] + confmat[[group]][["tn"]] + confmat[[group]][["fp"]] + confmat[[group]][["fn"]])
@@ -345,7 +346,7 @@ model_fairness <- function(data,
         odds.ratio[[group]][["lb"]] <- odds.ratio[["all"]][rowIndex, 2] <- .comp_lb_bayes(alternative, conf.level, analytical = FALSE, samples = samples_list[[group]]$OR)
         odds.ratio[[group]][["ub"]] <- odds.ratio[["all"]][rowIndex, 3] <- .comp_ub_bayes(alternative, conf.level, analytical = FALSE, samples = samples_list[[group]]$OR)
         odds.ratio[[group]][["bf10"]] <- odds.ratio[["all"]][rowIndex, 4] <- switch(alternative,
-          "two.sided" = .contingencyTableBf(contingencyTable, prior, "columns"),
+          "two.sided" = .contingencyTableBf(contingencyTable, prior, "none"),
           "less" = (length(which(samples_list[[group]]$OR < 1)) / length(samples_list[[group]]$OR)) / (length(which(samples_list[[group]]$OR > 1)) / length(samples_list[[group]]$OR)),
           "greater" = (length(which(samples_list[[group]]$OR > 1)) / length(samples_list[[group]]$OR)) / (length(which(samples_list[[group]]$OR < 1)) / length(samples_list[[group]]$OR))
         )
@@ -363,14 +364,14 @@ model_fairness <- function(data,
   if (metric != "dp") {
     nums <- unlist(lapply(metrics, function(group) group[["numerator"]]))
     denoms <- unlist(lapply(metrics, function(group) group[["denominator"]]))
-    crossTab <- matrix(c(nums, denoms - nums), nrow = 2, byrow = TRUE)
+    crossTab <- matrix(c(nums, denoms - nums), nrow = 2, byrow = TRUE) # Contingency table used for bf robustness check
     colnames(crossTab) <- groups
     if (!is_bayesian) {
       suppressWarnings({ # Temporary until better solution
         test <- stats::chisq.test(crossTab)
       })
     } else {
-      bf <- .contingencyTableBf(crossTab, prior, "columns")
+      bf <- .contingencyTableBf(crossTab, prior, "none")
       names(bf) <- "BF10"
     }
   }
